# Astromesh Code of Conduct

Astromesh, this repository, and the project materials included in it are
the property of Monaccode Technology LLC, except where third-party
components remain subject to their respective licenses and ownership.

## Our Pledge

We pledge to create a welcoming and respectful environment for everyone
participating in the Astromesh community.

We are committed to making participation in the project a
harassment-free experience regardless of age, body size, disability,
ethnicity, gender identity, experience level, nationality, personal
appearance, race, religion, or sexual identity.

------------------------------------------------------------------------

## Expected Behavior

Participants are expected to:

• Be respectful and inclusive\
• Welcome new contributors\
• Accept constructive feedback\
• Focus on what is best for the community

------------------------------------------------------------------------

## Unacceptable Behavior

The following behaviors are not tolerated:

• Harassment or discrimination\
• Personal attacks or insults\
• Trolling or deliberate disruption\
• Publishing private information without consent

------------------------------------------------------------------------

## Enforcement

Project maintainers are responsible for enforcing the Code of Conduct.

They may remove or edit comments, commits, issues, or other
contributions that violate this Code of Conduct.

------------------------------------------------------------------------

## Reporting Issues

If you experience or witness unacceptable behavior, please contact the
project maintainers.

Contact:

security@astromesh.ai
